@@ -2,8 +2,7 @@ describe.bprobit<-function(){
 category <- "dichotomous"
 description  <- "Bivariate Probit Regression for Dichotomous Dependent Variables"
 package <-list(	name 	="VGAM",
-		version	="0.6",
-		CRAN    ="http://www.stat.auckland.ac.nz/~yee"
+		version	="0.6"
 		)
 parameters<-list(mu="mu", rho="rho")
 parameters$mu<-list(equations=c(2,2),
