@@ -1,6 +1,6 @@
-names.zelig <- function (x, ...) {
-   res <- names.default(x, ...)[1:5]
-   qi.names <- names.default(x$qi, ...)
+names.zelig <- function (x) {
+   res <- names(unclass(x))[1:5]
+   qi.names <- names(x$qi)
    for (i in 1:length(qi.names)) {
      qi.names[i] <- paste("qi$", qi.names[i], sep = "")
   }
